@@ -4,7 +4,7 @@ import abc
 
 class Repository(metaclass=abc.ABCMeta):
     """The base class for all :term:`Repository` implementations."""
-    
+
     #: Raised when a new entity with an existing key is being persisted.
     Duplicate = type('Duplicate', (Exception,), {})
 
@@ -22,7 +22,8 @@ class Repository(metaclass=abc.ABCMeta):
         provided implementation class `impl`.
         """
         return type('%sRepository' % impl.__name__, (impl, cls), {
-            '__module__': impl.__module__
+            '__module__': impl.__module__,
+            '_in_transaction': False
         })
 
     @classmethod
